@@ -78,7 +78,7 @@ main(gint argc, gchar **argv)
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print ("%s\n", "Copyright (c) 2008-2010");
+        g_print ("%s\n", "Copyright (c) 2008-2011");
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
@@ -96,12 +96,17 @@ main(gint argc, gchar **argv)
         return EXIT_FAILURE;
     }
 
+    /* We don't want a gradient on our toolbar */
+    gtk_rc_parse_string ("style \"xfce-no-shadow\"\n"
+                         "{\n"
+                           "GtkToolbar::shadow-type = GTK_SHADOW_NONE\n"
+                         "}\n"
+                         "class \"*\" style \"xfce-no-shadow\"\n");
+
     dialog = xfce4_settings_editor_main_window_new();
 
     gtk_dialog_run (dialog);
 
-    gtk_widget_destroy (GTK_WIDGET (dialog));
-
     /* shutdown xfconf */
     xfconf_shutdown ();
 
